library(ggplot2)
library(raster)
library(tidyverse)
library(rasterVis)
library(reshape2)
library(rgdal)
library(RColorBrewer)

#Pull in simulation outputs and reshape
setwd("./data_folder_peerj")
all.scenarios<-read.csv("all.scenarios.csv")
all.scenarios.melt2<-melt(all.scenarios, id.vars = c("scenario", "X.run.number.", "X.step.", "experiment"))

#Labeling for plotting 
cols <- c("mortality" = "#CC79A7", "depl_mort" = "#56B4E9", "deplete" = "#009E73", "baseline" = "#E69F00")
scenario_names <- as_labeller(c(`original_rd_config` = "Existing Road Configuration", `both_rail_rd_config` = "Existing Roads Plus Proposed Railway"))
pop_change_names <- as_labeller(c(`total.offspring` = "Dependent Offspring", `count.breeding.females` = "Breeding Females", `total.adults` = "Total Adults"))
mort_rate_names <- as_labeller(c(`rd1.mort.prop` = "Primary Roads", `rd2.mort.prop` = "Secondary Roads", `rd12.mort.prop` = "Both Road Types"))
mort_count_names <- as_labeller(c(`total.road1.mort` = "Primary Roads", `total.road2.mort` = "Secondary Roads", `total.road12.mort` = "Both Road Types"))
fem_offspring_mort_names <-as_labeller(c(`dead.fem.roads12` = "Adult Females",`dead.cubs.juv.road12` = "Dependent Offspring"))
boxplot_mort_names <-as_labeller(c(`total.road12.mort` = "Total Animals", `dead.fem.roads12` = "Adult Females",`dead.cubs.juv.road12` = "Dependent Offspring"))

#Plotting total adults (fig3)
population.sizes <- all.scenarios.melt2 %>% filter(variable %in% c("total.offspring", "count.breeding.females", "total.adults"), scenario != "rail_only_config") %>% 
  ggplot(aes(x=X.step., y=as.numeric(value), color=experiment, group=experiment)) + 
  stat_summary(geom="ribbon", fun.data=mean_cl_normal, alpha = 0.3) + 
  stat_summary(fun="mean", geom="line", size = 1.5) + 
  xlab("Simulation Year") + ylab("Number of Animals") +
  theme_bw()+ theme(axis.text=element_text(size=16), axis.title=element_text(size=18,face="bold"), 
                    legend.title=element_blank(), legend.text=element_text(size=16), legend.key.size = unit(3, 'lines')) + 
  scale_x_continuous(breaks = seq(0, 20, by=2)) + 
  scale_color_manual(labels = c("Tiger Mortality", "Prey Depletion & \nTiger Mortality","Prey Depletion", "Baseline\n(no road impacts)"), values = cols) + 
  facet_grid(variable ~ scenario, labeller= labeller(variable = pop_change_names, scenario = scenario_names), scales = "free") + 
  theme(legend.position="bottom") + theme(strip.text.x = element_text(size = 16)) + theme(strip.text.y = element_text(size = 16))
#ggsave(population.sizes, file = "pop_sizes.png", dpi = 300)

#Report beginning and end values of simulation outputs (to create table 1)
pop.sizes<-ggplot_build(population.sizes)$data[[2]]
end_pop_sizes<-pop.sizes %>% group_by(colour, PANEL) %>% do(tail(.,n=1))
start_pop_sizes<-pop.sizes %>% group_by(colour, PANEL) %>% do(head(.,n=1))
write.csv(start_pop_sizes, "start_pop_sizes.csv")
write.csv(end_pop_sizes, "end_pop_sizes.csv")

#Plot mortality rates (fig 4)
mort.roads.rate <- all.scenarios.melt2 %>% filter(variable %in% c("rd1.mort.prop","rd2.mort.prop","rd12.mort.prop"), scenario != "rail_only_config") %>% 
  ggplot(aes(x=cut(X.step., breaks), y=as.numeric(value), color=experiment, group=experiment)) + 
  stat_summary(fun="mean", geom="line", size = 1) +
  #stat_summary_bin(fun="mean", geom="line", size = 2, bins = 10) +  
  stat_summary(fun.data = mean_se, geom = "errorbar", width=0.1, size = 0.5, position=position_dodge(width=0.5)) +
  xlab("Simulation Year") + ylab("Mortality When Territory Crossed by Road / Total Mortality") +
  theme_bw()+ theme(axis.text=element_text(size=16), axis.title=element_text(size=18,face="bold"), 
                    legend.title=element_blank(), legend.text=element_text(size=16), legend.key.size = unit(3, 'lines')) + 
  scale_x_discrete(labels = c(1,"","","",5,"","","","",10,"","","","",15,"","","","",20)) + #scale_x_discrete(breaks = seq(0, 20, by=2)) + 
  scale_color_manual(labels = c("Tiger Mortality", "Prey Depletion & \nTiger Mortality","Prey Depletion", "Baseline\n(no road impacts)"), values = cols) + 
  facet_grid(variable ~ scenario, labeller= labeller(variable = mort_rate_names, scenario = scenario_names)) + 
  theme(legend.position="bottom") + theme(strip.text.x = element_text(size = 16)) + theme(strip.text.y = element_text(size = 16))#+ coord_cartesian(ylim = c(0, .01)) 
#ggsave(mort.roads.rate, file = "Mort_roads_rate.png", dpi = 300)
#write.csv(ggplot_build(mort.roads.rate)$data[[1]], "mort_roads_rate.csv")

#boxplots
all.scenarios.filtered <-all.scenarios.melt2 %>% filter(variable %in% c("dead.fem.roads12","dead.cubs.juv.road12","total.road12.mort"), scenario != "rail_only_config")
mort_sums <- all.scenarios.filtered %>% 
  group_by(experiment, scenario, X.run.number., variable) %>%
  summarize(sum_road1_mort = sum(as.numeric(value)))

plot_mort_sums <- mort_sums %>% ggplot(., aes(x=experiment, y=sum_road1_mort, fill = experiment)) + geom_boxplot() + 
  stat_summary(fun=mean, geom="point", shape=18, size=3, color="darkred") +
  xlab("Scenario") + ylab("Mortality When Territory Crossed by Roads Over 20-year Simulation") +
  theme_bw() + theme(axis.text=element_text(size=16), axis.title=element_text(size=18,face="bold"), 
                     axis.text.x=element_text(color = "black", size=14, angle=30, vjust=.8, hjust=0.8), legend.position = "none") + 
  scale_fill_manual(labels = c("Tiger Mortality", "Prey Depletion & \nTiger Mortality","Prey Depletion", "Baseline\n(no road impacts)"), values = cols) + 
  scale_x_discrete(labels = c("Baseline\n(no road impacts)", "Prey Depletion & \nTiger Mortality","Prey Depletion", "Tiger Mortality")) +
  facet_grid(variable ~ scenario, labeller= labeller(variable = boxplot_mort_names, scenario = scenario_names), scales = "free") + 
  theme(strip.text.x = element_text(size = 16)) + theme(strip.text.y = element_text(size = 16))
#ggsave(plot_mort_sums, file = "plot_mort_sums.png", dpi = 300)


##Create maps of occupancy!
L_base=list.files("occupancies/", pattern = "resultsnoneoriginalfalse")
can_l_base <- lapply(L_base, read.csv)
new_col_name <- c("X", "Y", "Occupied")
base.park<-lapply(can_l_base, setNames, nm=new_col_name)
base.park.ras<-lapply(base.park, rasterFromXYZ)
base.park.stack<-stack(base.park.ras)
base.park.scaled<-base.park.stack/240
base.park.scaled.mn <- calc(base.park.scaled, fun = mean)
#plot(base.park.scaled.mn)
#writeRaster(base.park.scaled.mn, "base_park_scaled_mn.tif")

L_mort=list.files("occupancies/", pattern = "resultsnoneoriginaltrue")
can_l_mort <- lapply(L_mort, read.csv)
new_col_name <- c("X", "Y", "Occupied")
mort.yes<-lapply(can_l_mort, setNames, nm=new_col_name)
mort.yes.ras<-lapply(mort.yes, rasterFromXYZ)
mort.yes.stack<-stack(mort.yes.ras)
mort.yes.scaled<-mort.yes.stack/240
mort.yes.scaled.mn <- calc(mort.yes.scaled, fun = mean)
#plot(mort.yes.scaled.mn)
#writeRaster(mort.yes.scaled.mn, "mort_yes_scaled_mn.tif")

L_depl=list.files("occupancies/", pattern = "resultsdepleteoriginalfalse")
can_l_depl <- lapply(L_depl, read.csv)
new_col_name <- c("X", "Y", "Occupied")
depl.park<-lapply(can_l_depl, setNames, nm=new_col_name)
depl.park.ras<-lapply(depl.park, rasterFromXYZ)
depl.park.stack<-stack(depl.park.ras)
depl.park.scaled<-depl.park.stack/240
depl.park.scaled.mn <- calc(depl.park.scaled, fun = mean)
#plot(depl.park.scaled.mn)
#writeRaster(depl.park.scaled.mn, "depl_park_scaled_mn.asc", format="ascii")

L_depl_mort=list.files("occupancies/", pattern = "resultsdepleteoriginaltrue")
can_l_depl_mort <- lapply(L_depl_mort, read.csv)
new_col_name <- c("X", "Y", "Occupied")
deplete.mort<-lapply(can_l_depl_mort, setNames, nm=new_col_name)
deplete.mort.ras<-lapply(deplete.mort, rasterFromXYZ)
deplete.mort.stack<-stack(deplete.mort.ras)
deplete.mort.scaled<-deplete.mort.stack/240
deplete.mort.scaled.mn <- calc(deplete.mort.scaled, fun = mean)
deplete.mort.scaled.sd <- calc(deplete.mort.scaled, fun = sd)
#plot(deplete.mort.scaled.mn)
#writeRaster(deplete.mort.scaled.mn, "deplete_mort_scaled_mn.tif")

#Plot figure 6
occupancies<-stack(base.park.scaled.mn,mort.yes.scaled.mn,depl.park.scaled.mn,deplete.mort.scaled.mn)
names(occupancies) <- c('Baseline', 'Tiger Mortality', 'Prey Depletion','Prey Depletion and Tiger Mortality')
levelplot(occupancies)

# Calculate differences in occupancies between experiments
base.mort.occu<-base.park.scaled.mn - mort.yes.scaled.mn
base.depl.occu<-base.park.scaled.mn - depl.park.scaled.mn
base.deplmort.occu<-base.park.scaled.mn - deplete.mort.scaled.mn
base.diff.occupancies<-stack(base.mort.occu,base.depl.occu,base.deplmort.occu)
names(base.diff.occupancies) <- c('Baseline - Mortality', 'Baseline - Depletion', 'Baseline - Depletion&Mortality')
names_occupancies<-c('Baseline - Mortality', 'Baseline - Depletion', 'Baseline - Depletion&Mortality')
cellStats(base.diff.occupancies, stat='mean', na.rm=TRUE)

#Plot the difference in occupances and overlap the roads (Fig 7).
rd1.vector<-readOGR("gis_data", 'rd1_abm')
rd2.vector<-readOGR("gis_data", 'rd2_abm')
cols <- colorRampPalette(brewer.pal(9,"PuOr"))
cutpts <- c(-1,-0.8,-0.6,-0.4,-0.2,0,0.2,0.4,0.6,0.8,1)
occu.diff<-levelplot(base.diff.occupancies, layout=c(1, 3), names.attr=names_occupancies, at=cutpts, cuts=11, col.regions=(rev(brewer.pal(10,"PuOr"))))
occu.diff + latticeExtra::layer(sp.lines(rd2.vector, col="gray30", lwd=0.5)) + 
  latticeExtra::layer(sp.lines(rd1.vector, lwd=2))

# Calculate occupancies and prey values near and far from roads. First bring in the raster road data
road.original<-read.csv("gis_data/road_map_original.csv")
names(road.original)[1]<- "X"
names(road.original)[2]<- "Y"
names(road.original)[3]<- "road_cat"
rd.orig.ras<-rasterFromXYZ(road.original)
#writeRaster(rd.orig.ras, "rd_orig_ras.tif")

#Buffer and extract occupancy values near cat 1 road (20 pixels or 5 km)
rd.cat1 <- rd.orig.ras == 1
rd.cat1[rd.cat1 < 1] = NA
rd.cat1.buff <-buffer(rd.cat1, width = 20, dissolve=TRUE)
rd.cat1.buff.cl<-crop(rd.cat1.buff, base.park.scaled.mn)
rd.cat1.occu.base <- mask(base.park.scaled.mn, rd.cat1.buff.cl)
rd.cat1.occu.mort <- mask(mort.yes.scaled.mn, rd.cat1.buff.cl)
rd.cat1.occu.depl <- mask(depl.park.scaled.mn, rd.cat1.buff.cl)
rd.cat1.occu.depl.mort <- mask(deplete.mort.scaled.mn, rd.cat1.buff.cl)

#Calculate mean values
cellStats(rd.cat1.occu.base, stat='mean', na.rm=TRUE)
cellStats(rd.cat1.occu.mort, stat='mean', na.rm=TRUE)
cellStats(rd.cat1.occu.depl, stat='mean', na.rm=TRUE)
cellStats(rd.cat1.occu.depl.mort, stat='mean', na.rm=TRUE)

#Buffer and extract occupancy values near cat 2 road (8 pixels or 2 km)
rd.cat2 <- rd.orig.ras == 2
rd.cat2[rd.cat2 < 1] = NA

rd.cat2.buff <-buffer(rd.cat2, width = 8, dissolve=TRUE)
rd.cat2.buff.cl<-crop(rd.cat2.buff, base.park.scaled.mn)
rd.cat2.occu.base <- mask(base.park.scaled.mn, rd.cat2.buff.cl)
rd.cat2.occu.mort <- mask(mort.yes.scaled.mn, rd.cat2.buff.cl)
rd.cat2.occu.depl <- mask(depl.park.scaled.mn, rd.cat2.buff.cl)
rd.cat2.occu.depl.mort <- mask(deplete.mort.scaled.mn, rd.cat2.buff.cl)

#Calculate mean values
cellStats(rd.cat2.occu.base, stat='mean', na.rm=TRUE)
cellStats(rd.cat2.occu.mort, stat='mean', na.rm=TRUE)
cellStats(rd.cat2.occu.depl, stat='mean', na.rm=TRUE)
cellStats(rd.cat2.occu.depl.mort, stat='mean', na.rm=TRUE)

#Occupancy values away from cat 1 roads
rd.cat1.occu.base.inverse <- mask(base.park.scaled.mn, rd.cat1.buff.cl, inverse=TRUE)
rd.cat1.occu.mort.inverse <- mask(mort.yes.scaled.mn, rd.cat1.buff.cl, inverse = TRUE)
rd.cat1.occu.depl.inverse <- mask(depl.park.scaled.mn, rd.cat1.buff.cl, inverse = TRUE)
rd.cat1.occu.depl.mort.inverse <- mask(deplete.mort.scaled.mn, rd.cat1.buff.cl, inverse = TRUE)

#Calculate mean values
cellStats(rd.cat1.occu.base.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat1.occu.mort.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat1.occu.depl.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat1.occu.depl.mort.inverse, stat='mean', na.rm=TRUE)

#Occupancy values away from cat 2 roads
rd.cat2.occu.base.inverse <- mask(base.park.scaled.mn, rd.cat2.buff.cl, inverse=TRUE)
rd.cat2.occu.mort.inverse <- mask(mort.yes.scaled.mn, rd.cat2.buff.cl, inverse = TRUE)
rd.cat2.occu.depl.inverse <- mask(depl.park.scaled.mn, rd.cat2.buff.cl, inverse = TRUE)
rd.cat2.occu.depl.mort.inverse <- mask(deplete.mort.scaled.mn, rd.cat2.buff.cl, inverse = TRUE)

cellStats(rd.cat2.occu.base.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat2.occu.mort.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat2.occu.depl.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat2.occu.depl.mort.inverse, stat='mean', na.rm=TRUE)

#Occupancies values from both road categories
rd.cat12.buff<-merge(rd.cat1.buff.cl, rd.cat2.buff.cl)
rd.cat12.occu.base <- mask(base.park.scaled.mn, rd.cat12.buff)
rd.cat12.occu.mort <- mask(mort.yes.scaled.mn, rd.cat12.buff)
rd.cat12.occu.depl <- mask(depl.park.scaled.mn, rd.cat12.buff)
rd.cat12.occu.depl.mort <- mask(deplete.mort.scaled.mn, rd.cat12.buff)

cellStats(rd.cat12.occu.base, stat='mean', na.rm=TRUE)
cellStats(rd.cat12.occu.mort, stat='mean', na.rm=TRUE)
cellStats(rd.cat12.occu.depl, stat='mean', na.rm=TRUE)
cellStats(rd.cat12.occu.depl.mort, stat='mean', na.rm=TRUE)

rd.cat12.occu.base.inverse <- mask(base.park.scaled.mn, rd.cat12.buff, inverse=TRUE)
rd.cat12.occu.mort.inverse <- mask(mort.yes.scaled.mn, rd.cat12.buff, inverse = TRUE)
rd.cat12.occu.depl.inverse <- mask(depl.park.scaled.mn, rd.cat12.buff, inverse = TRUE)
rd.cat12.occu.depl.mort.inverse <- mask(deplete.mort.scaled.mn, rd.cat12.buff, inverse = TRUE)

cellStats(rd.cat12.occu.base.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat12.occu.mort.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat12.occu.depl.inverse, stat='mean', na.rm=TRUE)
cellStats(rd.cat12.occu.depl.mort.inverse, stat='mean', na.rm=TRUE)

# Prey values near and far from roads
prey<-read.csv("gis_data/prey_map.csv")
names(prey)[1]<- "X"
names(prey)[2]<- "Y"
names(prey)[3]<- "prey"
prey.map<-rasterFromXYZ(prey)
prey.map.near.roads <- mask(prey.map, rd.cat12.buff)
prey.map.far.roads <- mask(prey.map, rd.cat12.buff, inverse = TRUE)
cellStats(prey.map.near.roads, stat='mean', na.rm=TRUE)
cellStats(prey.map.far.roads, stat='mean', na.rm=TRUE)

#Calculating mean difference in occupancy between scenarios
base_mort_diff<-as.data.frame(base.park.scaled.mn - mort.yes.scaled.mn)
mean.diff.base.mort<-base_mort_diff %>% 
  drop_na(layer) %>% 
  summarise(mean = mean(layer))
mean.diff.base.mort

base_depl_diff<-as.data.frame(base.park.scaled.mn - depl.park.scaled.mn)
mean.diff.base.depl<-base_depl_diff %>% 
  drop_na(layer) %>% 
  summarise(mean = mean(layer))
mean.diff.base.depl

base_deplmort_diff<-as.data.frame(base.park.scaled.mn - deplete.mort.scaled.mn)
mean.diff.base.deplmort<-base_deplmort_diff %>% 
  drop_na(layer) %>% 
  summarise(mean = mean(layer))
mean.diff.base.deplmort
